"use client";

import React, { useEffect, useState, Suspense } from 'react';
import { useSearchParams } from 'next/navigation';
import CompanyPage from '@/app/components/CompanyPage'; 
import Head from 'next/head';
import AdSense from '@/app/components/AdSense';

const CompanyDetailContent: React.FC = () => {
  const searchParams = useSearchParams();
  const companyId = searchParams.get('id'); // Get the companyId from the query parameter

  const [companyIdNumber, setCompanyIdNumber] = useState<number | null>(null);
  const [companyData, setCompanyData] = useState<any>(null); // State to hold company data

  useEffect(() => {
    if (companyId) {
      const parsedId = parseInt(companyId, 10);
      setCompanyIdNumber(parsedId);

      // Fetch company data (adjust this to your actual data fetching method)
      const fetchCompanyData = async () => {
        try {
          const response = await fetch(`/api/company/${parsedId}`); // Example API call
          const data = await response.json();
          setCompanyData(data);
        } catch (error) {
          console.error('Error fetching company data:', error);
        }
      };

      fetchCompanyData();
    }
  }, [companyId]);

  if (!companyIdNumber || !companyData) {
    return <div>Loading...</div>;
  }

  return (
    <>
      <Head>
        <title>{`${companyData.name} - Company Details | Delgor`}</title>
        <meta name="description" content={`Explore movies and TV shows from ${companyData.name}. Discover the best content produced by ${companyData.name}.`} />
        <link rel="canonical" href={`https://www.delgor.com/company?id=${companyIdNumber}`} />
        <meta property="og:title" content={`${companyData.name} - Company Details | Delgor`} />
        <meta property="og:description" content={`Explore movies and TV shows from ${companyData.name}. Discover the best content produced by ${companyData.name}.`} />
        <meta property="og:type" content="website" />
        <meta property="og:url" content={`https://www.delgor.com/company?id=${companyIdNumber}`} />
        <meta property="og:image" content={companyData.logo_path ? `https://image.tmdb.org/t/p/w500${companyData.logo_path}` : '/images/fallback-company.png'} /> {/* Replace with the actual image or fallback */}
        <meta property="og:image:alt" content={`${companyData.name} Logo`} />
        <meta property="og:site_name" content="Delgor" />
        {/* Structured Data for Company */}
        <script type="application/ld+json">
          {JSON.stringify({
            "@context": "https://schema.org",
            "@type": "Organization",
            "name": companyData.name,
            "description": `Explore movies and TV shows from ${companyData.name}.`,
            "url": `https://www.delgor.com/company?id=${companyIdNumber}`,
            "logo": companyData.logo_path ? `https://image.tmdb.org/t/p/w500${companyData.logo_path}` : '/images/fallback-company.png',
          })}
        </script>
      </Head>
      <CompanyPage companyId={companyIdNumber} />
      <div className="w-full my-4">
          <AdSense />
        </div>
    </>
  );
};

const CompanyDetail: React.FC = () => {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <CompanyDetailContent />
    </Suspense>
  );
};

export default CompanyDetail;
